@@ -348,7 +348,7 @@ def aggregate(ds,wm):
     ds = subset_find(ds,wm.source_grid)
     
     # Set weights; or replace with ones if no additional weight information
-    if 'weights' in gdf_out.keys():
+    if wm.weights is not 'nowghts':
         weights = np.array([float(k) for k in wm.weights])
     else:
         weights = np.ones((len(wm.source_grid['lat']),1))
@@ -362,20 +362,19 @@ def aggregate(ds,wm):
             wm.agg[var] = None
             #breakpoint()
             # Get weighted average of variable based on pixel overlap + other weights
-            for poly_idx in gdf_out['agg'].poly_idx:
+            for poly_idx in wm.agg.poly_idx:
                 # Get average value of variable over the polygon; weighted by 
                 # how much of the pixel area is in the polygon, and by (optionally)
                 # a separate gridded weight
-                try:
-                    if wm.agg.iloc[poly_idx,:].pix_idxs is not np.nan:
-                        wm.agg.loc[poly_idx,var] = [[((ds[var].isel(loc=wm.agg.iloc[poly_idx,:].pix_idxs)*
-                                                               normalize(np.squeeze(wm.agg.iloc[poly_idx,:].rel_area)*
-                                                                 weights[wm.agg.iloc[poly_idx,:].pix_idxs])).
-                                                              sum('loc')).values]]
-                    else:
-                        wm.agg.loc[poly_idx,var] = [[np.array(np.nan)]]
-                except:
-                    breakpoint()
+                if wm.agg.iloc[poly_idx,:].pix_idxs is not np.nan:
+                    wm.agg.loc[poly_idx,var] = [[((ds[var].isel(loc=wm.agg.iloc[poly_idx,:].pix_idxs)*
+                                                           normalize(np.squeeze(wm.agg.iloc[poly_idx,:].rel_area)*
+                                                             weights[wm.agg.iloc[poly_idx,:].pix_idxs])).
+                                                          sum('loc')).values]]
+                else:
+                    #breakpoint()
+                    #wm.agg.loc[poly_idx,var] = [[np.array(np.nan)]]
+                    wm.agg.loc[poly_idx,var] = [[(ds[var].isel(loc=0)*np.nan).values]]
                 
     # Put in class format
     agg_out = aggregated(agg=wm.agg,source_grid=wm.source_grid,
